#!/bin/sh
#
#File name: set_ntsc_pal_height.sh 
#ali@evertz.com. Dec-2008
#
#To set the correct height for Vidstd (PAL or NTSC) in encoder configurration file vid_enc_cfg_720x480.txt
#When std is pal, all height values will be set to 480, otherwise 576
#
#Usage: 
#./set_ntsc_pal_height.sh h264
# or 
#./set_ntsc_pal_height.sh mpeg2

#Files used:
encoder_cfg_file="/mnt/flashdisk/vid_enc_cfg_720x480.txt"
out_cfg_file="./cfg_back"
temp_file="/tmp/temp_cfg"

#Related lines in vid_enc_cfg_720x480.txt of h264 encoder(576 for PAL):
	#u2_cap_ht               = 480       # Height of the captured frame
	#u2_src_ht               = 480       # Height of the input seq
	#u2_trgt_ht              = 480       # Target Height to encode
	#VidStd                  = __NTSC__     # Video Standard __NTSC__ or __PAL__
	
#Related lines in vid_enc_cfg_720x480.txt of mpeg2 encoder(576 for PAL):
	#i4_max_height           = 480
	#i4_frm_height           = 480
	#i4_tgt_height           = 480	
	#VidStd                  = __NTSC__     # Video Standard __NTSC__ or __PAL__
	
#
# List of parameters to parse and reserve 
if [ "$1" = h264 ]; then
std_para_list="
u2_cap_ht
u2_src_ht
u2_trgt_ht
"
elif [ "$1" = mpeg2 ]; then
std_para_list="
i4_max_height
i4_frm_height
i4_tgt_height
"
else
   echo "set_ntsc_pal_height.sh error: parameter h264 or mpeg2 not provided"
   return 1
fi

#Function to set the correct height for Vidstd (PAL or NTSC)
#Usage: std_parse_and_replace. When std is pal, all height val is set to 480, otherwise 576
std_parse_and_replace(){
	ntsc_std="__NTSC__"
	pal_std="__PAL__"
	pal_height="576"
	ntsc_height="480"
	
	#Parse this line: VidStd                  = __NTSC__     # Video Standard
 	VideoStandard=`grep "VidStd.*=.*"  $out_cfg_file | cut -d "=" -f 2 | cut -d "#" -f 1`
	if [ -z $VideoStandard ]; then
	   echo "std_parse_and_replace() error: VidStd Not Exist in file $out_cfg_file"
	   return 2
	fi
	if [ $VideoStandard = $ntsc_std ]; then
		height_value=$ntsc_height
	elif [ $VideoStandard = $pal_std ]; then
		height_value=$pal_height
	else	
	   echo "std_parse_and_replace() error: VideoStandard is $VideoStandard, should be [$ntsc_std] or [$pal_std]"
	   return 2
	fi

	#Find and replace:
	for para in $std_para_list
	do
	   new_para="$para            = $height_value " #Consist of 2 parts
	   echo "new_para is [$new_para]"
	   sed "s/$para.*=.*/$new_para/g" $out_cfg_file  > $temp_file
	   cp $temp_file $out_cfg_file
	done
	return 0
}
 
if [ ! -f $encoder_cfg_file ]; then
	echo "Can't find file [$encoder_cfg_file], exit. "
	exit 1
fi

#Get a temp copy of $out_cfg_file
cp $encoder_cfg_file $out_cfg_file 

#Set capture height value according to current video standard(PAL or NTSC)
std_parse_and_replace
  
cp $out_cfg_file $encoder_cfg_file
chmod 666 $encoder_cfg_file
rm -f $out_cfg_file $temp_file
exit 0
